@@ -228,7 +228,7 @@ impl LdapDirectory {
                         .map_err(|err| err.into_error().caused_by(trc::location!()))?;
                     for entry in rs {
                         'outer: for (attr, value) in SearchEntry::construct(entry).attrs {
-                            if self.mappings.attr_name.contains(&attr)
+                            if self.mappings.attr_name.contains(&attr.to_lowercase())
                                 && let Some(group) = value.into_iter().next()
                                 && !group.is_empty()
                             {
@@ -310,14 +310,13 @@ impl LdapDirectory {
         );
 
         for entry in rs {
-            let entry = SearchEntry::construct(entry);
-            for attr in &self.mappings.attr_name {
-                if let Some(name) = entry.attrs.get(attr).and_then(|v| v.first())
-                    && !name.is_empty()
+            for (attr, value) in SearchEntry::construct(entry).attrs {
+                if self.mappings.attr_name.contains(&attr.to_lowercase())
+                    && let Some(name) = value.into_iter().find(|name| !name.is_empty())
                 {
                     return self
                         .data_store
-                        .get_or_create_principal_id(name, Type::Individual)
+                        .get_or_create_principal_id(&name, Type::Individual)
                         .await
                         .map(Some);
                 }
@@ -436,6 +435,7 @@ impl LdapMappings {
         let mut email_aliases = Vec::new();
 
         for (attr, value) in entry.attrs {
+            let attr = attr.to_lowercase();
             if self.attr_name.contains(&attr) {
                 if !self.attr_email_address.contains(&attr) {
                     principal.name = value.into_iter().next().unwrap_or_default();
