@@ -4,7 +4,7 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
-use common::{MessageStoreCache, Server};
+use common::{DavResources, MessageStoreCache, Server};
 use jmap_proto::types::state::State;
 use std::future::Future;
 use trc::AddContext;
@@ -25,10 +25,18 @@ pub trait StateManager: Sync + Send {
     ) -> impl Future<Output = trc::Result<State>> + Send;
 }
 
-pub trait MessageCacheState: Sync + Send {
-    fn get_state(&self, is_mailbox: bool) -> State;
+pub trait JmapCacheState: Sync + Send {
+    fn get_state(&self, is_container: bool) -> State;
 
-    fn assert_state(&self, is_mailbox: bool, if_in_state: &Option<State>) -> trc::Result<State>;
+    fn assert_state(&self, is_container: bool, if_in_state: &Option<State>) -> trc::Result<State> {
+        let old_state: State = self.get_state(is_container);
+        if let Some(if_in_state) = if_in_state
+            && &old_state != if_in_state
+        {
+            return Err(trc::JmapEvent::StateMismatch.into_err());
+        }
+        Ok(old_state)
+    }
 }
 
 impl StateManager for Server {
@@ -59,22 +67,22 @@ impl StateManager for Server {
     }
 }
 
-impl MessageCacheState for MessageStoreCache {
-    fn get_state(&self, is_mailbox: bool) -> State {
-        if is_mailbox {
+impl JmapCacheState for MessageStoreCache {
+    fn get_state(&self, is_container: bool) -> State {
+        if is_container {
             State::from(self.mailboxes.change_id)
         } else {
             State::from(self.emails.change_id)
         }
     }
+}
 
-    fn assert_state(&self, is_mailbox: bool, if_in_state: &Option<State>) -> trc::Result<State> {
-        let old_state: State = self.get_state(is_mailbox);
-        if let Some(if_in_state) = if_in_state
-            && &old_state != if_in_state
-        {
-            return Err(trc::JmapEvent::StateMismatch.into_err());
+impl JmapCacheState for DavResources {
+    fn get_state(&self, is_container: bool) -> State {
+        if is_container {
+            State::from(self.container_change_id)
+        } else {
+            State::from(self.item_change_id)
         }
-        Ok(old_state)
     }
 }
