@@ -7,18 +7,16 @@
 pub mod analysis;
 pub mod modules;
 
-use std::borrow::Cow;
-use std::collections::HashSet;
-use std::hash::{Hash, Hasher};
-use std::net::{IpAddr, Ipv4Addr};
-
 use analysis::ElementLocation;
 use analysis::url::UrlParts;
-use compact_str::CompactString;
 use mail_auth::{ArcOutput, DkimOutput, DmarcResult, IprevOutput, SpfOutput, dmarc::Policy};
 use mail_parser::Message;
 use modules::html::HtmlToken;
 use nlp::tokenizers::types::TokenType;
+use std::borrow::Cow;
+use std::collections::HashSet;
+use std::hash::{Hash, Hasher};
+use std::net::{IpAddr, Ipv4Addr};
 use store::ahash::AHashSet;
 
 pub struct SpamFilterInput<'x> {
@@ -49,13 +47,13 @@ pub struct SpamFilterInput<'x> {
     pub env_from_flags: u64,
     pub env_rcpt_to: Vec<&'x str>,
 
-    pub account_id: Option<u32>,
+    pub is_train: bool,
     pub is_test: bool,
 }
 
 pub struct SpamFilterOutput<'x> {
     pub ehlo_host: Hostname,
-    pub iprev_ptr: Option<CompactString>,
+    pub iprev_ptr: Option<String>,
 
     pub env_from_addr: Email,
     pub env_from_postmaster: bool,
@@ -70,44 +68,44 @@ pub struct SpamFilterOutput<'x> {
     pub subject_lc: String,
     pub subject_thread: String,
     pub subject_thread_lc: String,
-    pub subject_tokens: Vec<TokenType<Cow<'x, str>, Email, UrlParts<'x>, IpParts<'x>>>,
+    pub subject_tokens: Vec<TokenType<Cow<'x, str>, Email, UrlParts<'x>, IpParts>>,
 
     pub ips: AHashSet<ElementLocation<IpAddr>>,
     pub urls: HashSet<ElementLocation<UrlParts<'x>>>,
     pub emails: HashSet<ElementLocation<Recipient>>,
-    pub domains: HashSet<ElementLocation<CompactString>>,
+    pub domains: HashSet<ElementLocation<String>>,
 
     pub text_parts: Vec<TextPart<'x>>,
 }
 
 #[derive(Debug)]
-pub struct IpParts<'x> {
+pub struct IpParts {
     ip: Option<IpAddr>,
-    text: Cow<'x, str>,
 }
 
 pub enum TextPart<'x> {
     Plain {
         text_body: &'x str,
-        tokens: Vec<TokenType<Cow<'x, str>, Email, UrlParts<'x>, IpParts<'x>>>,
+        tokens: Vec<TokenType<Cow<'x, str>, Email, UrlParts<'x>, IpParts>>,
     },
     Html {
         html_tokens: Vec<HtmlToken>,
         text_body: String,
-        tokens: Vec<TokenType<Cow<'x, str>, Email, UrlParts<'x>, IpParts<'x>>>,
+        tokens: Vec<TokenType<Cow<'x, str>, Email, UrlParts<'x>, IpParts>>,
     },
     None,
 }
 
 #[derive(Debug, Default)]
 pub struct SpamFilterResult {
-    pub tags: AHashSet<CompactString>,
-    pub score: f64,
+    pub tags: AHashSet<String>,
+    pub classifier_confidence: Vec<Option<f32>>,
+    pub score: f32,
     pub rbl_ip_checks: usize,
     pub rbl_domain_checks: usize,
     pub rbl_url_checks: usize,
     pub rbl_email_checks: usize,
-    pub header: Option<String>,
+    pub llm_result: Option<(String, String)>,
 }
 
 pub struct SpamFilterContext<'x> {
@@ -118,22 +116,22 @@ pub struct SpamFilterContext<'x> {
 
 #[derive(Debug, Clone)]
 pub struct Hostname {
-    pub fqdn: CompactString,
+    pub fqdn: String,
     pub ip: Option<IpAddr>,
-    pub sld: Option<CompactString>,
+    pub sld: Option<String>,
 }
 
 #[derive(Debug, Clone)]
 pub struct Email {
-    pub address: CompactString,
-    pub local_part: CompactString,
+    pub address: String,
+    pub local_part: String,
     pub domain_part: Hostname,
 }
 
 #[derive(Debug, Clone)]
 pub struct Recipient {
     pub email: Email,
-    pub name: Option<CompactString>,
+    pub name: Option<String>,
 }
 
 impl<'x> SpamFilterInput<'x> {
@@ -157,34 +155,14 @@ impl<'x> SpamFilterInput<'x> {
             env_from: "",
             env_from_flags: 0,
             env_rcpt_to: vec![],
-            account_id: None,
             is_test: false,
+            is_train: false,
         }
     }
 
-    pub fn from_account_message(message: &'x Message<'x>, account_id: u32, span_id: u64) -> Self {
-        Self {
-            message,
-            span_id,
-            arc_result: None,
-            spf_ehlo_result: None,
-            spf_mail_from_result: None,
-            dkim_result: &[],
-            dmarc_result: None,
-            dmarc_policy: None,
-            iprev_result: None,
-            remote_ip: IpAddr::V4(Ipv4Addr::LOCALHOST),
-            ehlo_domain: None,
-            authenticated_as: None,
-            asn: None,
-            country: None,
-            is_tls: true,
-            env_from: "",
-            env_from_flags: 0,
-            env_rcpt_to: vec![],
-            account_id: Some(account_id),
-            is_test: false,
-        }
+    pub fn train_mode(mut self) -> Self {
+        self.is_train = true;
+        self
     }
 }
 
@@ -217,6 +195,16 @@ impl Hash for Email {
 }
 
 impl Email {
+    pub fn classifier_parts(&self) -> Option<(&str, &str)> {
+        // Returns (local@, @domain)
+        if self.is_valid() {
+            let at_pos = self.address.find('@')?;
+            Some((&self.address[..=at_pos], &self.address[at_pos..]))
+        } else {
+            None
+        }
+    }
+
     pub fn is_valid(&self) -> bool {
         self.domain_part.sld.is_some() && !self.local_part.is_empty()
     }
