@@ -6,6 +6,8 @@
 
 use std::ops::Range;
 
+use crate::backend::postgres::into_pool_error;
+
 use super::{PostgresStore, into_error};
 
 impl PostgresStore {
@@ -14,7 +16,7 @@ impl PostgresStore {
         key: &[u8],
         range: Range<usize>,
     ) -> trc::Result<Option<Vec<u8>>> {
-        let conn = self.conn_pool.get().await.map_err(into_error)?;
+        let conn = self.conn_pool.get().await.map_err(into_pool_error)?;
         let s = conn
             .prepare_cached("SELECT v FROM t WHERE k = $1")
             .await
@@ -40,7 +42,7 @@ impl PostgresStore {
     }
 
     pub(crate) async fn put_blob(&self, key: &[u8], data: &[u8]) -> trc::Result<()> {
-        let conn = self.conn_pool.get().await.map_err(into_error)?;
+        let conn = self.conn_pool.get().await.map_err(into_pool_error)?;
         let s = conn
             .prepare_cached(
                 "INSERT INTO t (k, v) VALUES ($1, $2) ON CONFLICT (k) DO UPDATE SET v = EXCLUDED.v",
@@ -54,7 +56,7 @@ impl PostgresStore {
     }
 
     pub(crate) async fn delete_blob(&self, key: &[u8]) -> trc::Result<bool> {
-        let conn = self.conn_pool.get().await.map_err(into_error)?;
+        let conn = self.conn_pool.get().await.map_err(into_pool_error)?;
         let s = conn
             .prepare_cached("DELETE FROM t WHERE k = $1")
             .await
