@@ -4,9 +4,8 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
-use std::{fmt::Display, io::Write, ops::Range, time::Duration};
-
 use s3::{Bucket, Region, creds::Credentials};
+use std::{fmt::Display, io::Write, ops::Range, time::Duration};
 use utils::{
     codec::base32_custom::Base32Writer,
     config::{Config, utils::AsKey},
@@ -48,6 +47,9 @@ impl S3Store {
         let timeout = config
             .property_or_default::<Duration>((&prefix, "timeout"), "30s")
             .unwrap_or_else(|| Duration::from_secs(30));
+        /*let allow_invalid = config
+        .property_or_default::<bool>((&prefix, "tls.allow-invalid"), "false")
+        .unwrap_or_default();*/
 
         Some(S3Store {
             bucket: Bucket::new(
@@ -60,6 +62,11 @@ impl S3Store {
             })
             .ok()?
             .with_path_style()
+            /*.set_dangereous_config(allow_invalid, allow_invalid)
+            .map_err(|err| {
+                config.new_build_error(prefix.as_str(), format!("Failed to create bucket: {err:?}"))
+            })
+            .ok()?*/
             .with_request_timeout(timeout)
             .map_err(|err| {
                 config.new_build_error(prefix.as_str(), format!("Failed to create bucket: {err:?}"))
