@@ -5,12 +5,12 @@
  */
 
 use super::{
-    Batch, BatchBuilder, BitmapClass, ChangedCollection, IntoOperations, Operation, TagValue,
-    ValueClass, ValueOp, assert::ToAssertValue, log::VanishedItem,
+    Batch, BatchBuilder, ChangedCollection, IntoOperations, Operation, ValueClass, ValueOp,
+    assert::ToAssertValue, log::VanishedItem,
 };
 use crate::{
     SerializeInfallible, U32_LEN,
-    write::{LogCollection, MergeFn},
+    write::{LogCollection, MergeFnc, MergeOperation, Params, SetFnc, SetOperation},
 };
 use types::{
     collection::{Collection, SyncCollection, VanishedCollection},
@@ -54,39 +54,13 @@ impl BatchBuilder {
         self
     }
 
-    pub fn create_document(&mut self, document_id: u32) -> &mut Self {
-        self.ops.push(Operation::DocumentId { document_id });
-        self.ops.push(Operation::Bitmap {
-            class: BitmapClass::DocumentIds,
-            set: true,
-        });
-        self.current_document_id = Some(document_id);
-        self.batch_size += U32_LEN * 3;
-        self.batch_ops += 1;
-        self.has_assertions = false;
-        self
-    }
-
-    pub fn update_document(&mut self, document_id: u32) -> &mut Self {
+    pub fn with_document(&mut self, document_id: u32) -> &mut Self {
         self.ops.push(Operation::DocumentId { document_id });
         self.current_document_id = Some(document_id);
         self.has_assertions = false;
         self
     }
 
-    pub fn delete_document(&mut self, document_id: u32) -> &mut Self {
-        self.ops.push(Operation::DocumentId { document_id });
-        self.ops.push(Operation::Bitmap {
-            class: BitmapClass::DocumentIds,
-            set: false,
-        });
-        self.current_document_id = Some(document_id);
-        self.batch_size += U32_LEN * 3;
-        self.batch_ops += 1;
-        self.has_assertions = false;
-        self
-    }
-
     pub fn assert_value(
         &mut self,
         class: impl Into<ValueClass>,
@@ -131,34 +105,14 @@ impl BatchBuilder {
         self
     }
 
-    pub fn tag(&mut self, field: impl FieldType, value: impl Into<TagValue>) -> &mut Self {
-        let value = value.into();
-        let value_len = value.serialized_size();
-        self.ops.push(Operation::Bitmap {
-            class: BitmapClass::Tag {
-                field: field.into(),
-                value,
-            },
-            set: true,
-        });
-        self.batch_size += (U32_LEN * 3) + value_len;
-        self.batch_ops += 1;
-        self
+    #[inline(always)]
+    pub fn tag(&mut self, field: impl FieldType) -> &mut Self {
+        self.index(field, vec![])
     }
 
-    pub fn untag(&mut self, field: impl FieldType, value: impl Into<TagValue>) -> &mut Self {
-        let value = value.into();
-        let value_len = value.serialized_size();
-        self.ops.push(Operation::Bitmap {
-            class: BitmapClass::Tag {
-                field: field.into(),
-                value,
-            },
-            set: false,
-        });
-        self.batch_size += (U32_LEN * 3) + value_len;
-        self.batch_ops += 1;
-        self
+    #[inline(always)]
+    pub fn untag(&mut self, field: impl FieldType) -> &mut Self {
+        self.unindex(field, vec![])
     }
 
     pub fn add(&mut self, class: impl Into<ValueClass>, value: i64) -> &mut Self {
@@ -189,47 +143,35 @@ impl BatchBuilder {
         self.batch_size += class.serialized_size() + value.len();
         self.ops.push(Operation::Value {
             class,
-            op: ValueOp::Set {
-                value,
-                version_offset: None,
-            },
+            op: ValueOp::Set(value),
         });
         self.batch_ops += 1;
         self
     }
 
-    pub fn merge(
+    pub fn set_fnc(
         &mut self,
         class: impl Into<ValueClass>,
-        value: impl Fn(Option<&[u8]>) -> trc::Result<Vec<u8>> + Sync + Send + 'static,
+        params: Params,
+        fnc: SetFnc,
     ) -> &mut Self {
         self.ops.push(Operation::Value {
             class: class.into(),
-            op: ValueOp::Merge(MergeFn {
-                fnc: Box::new(value),
-                fnc_id: rand::random::<u64>(),
-            }),
+            op: ValueOp::SetFnc(SetOperation { fnc, params }),
         });
         self
     }
 
-    pub fn set_versioned(
+    pub fn merge_fnc(
         &mut self,
         class: impl Into<ValueClass>,
-        value: impl Into<Vec<u8>>,
-        version_offset: usize,
+        params: Params,
+        fnc: MergeFnc,
     ) -> &mut Self {
-        let class = class.into();
-        let value = value.into();
-        self.batch_size += class.serialized_size() + value.len();
         self.ops.push(Operation::Value {
-            class,
-            op: ValueOp::Set {
-                value,
-                version_offset: Some(version_offset),
-            },
+            class: class.into(),
+            op: ValueOp::MergeFnc(MergeOperation { fnc, params }),
         });
-        self.batch_ops += 1;
         self
     }
 
@@ -248,10 +190,7 @@ impl BatchBuilder {
         self.batch_size += (U32_LEN * 3) + op.len();
         self.ops.push(Operation::Value {
             class: ValueClass::Acl(grant_account_id),
-            op: ValueOp::Set {
-                value: op,
-                version_offset: None,
-            },
+            op: ValueOp::Set(op),
         });
         self.batch_ops += 1;
         self
