@@ -240,6 +240,7 @@ pub enum TaskQueueEvent {
     TaskAcquired,
     TaskLocked,
     TaskIgnored,
+    TaskFailed,
     BlobNotFound,
     MetadataNotFound,
 }
@@ -604,12 +605,14 @@ pub enum SpamEvent {
     PyzorError,
     Dnsbl,
     DnsblError,
-    Train,
-    TrainBalance,
-    TrainError,
+    TrainStarted,
+    TrainCompleted,
+    TrainSampleAdded,
+    TrainSampleNotFound,
     Classify,
-    ClassifyError,
-    TrainAccount,
+    ModelLoaded,
+    ModelNotReady,
+    ModelNotFound,
 }
 
 #[event_type]
@@ -714,7 +717,7 @@ pub enum PurgeEvent {
     Error,
     InProgress,
     AutoExpunge,
-    TombstoneCleanup,
+    BlobCleanup,
 }
 
 #[event_type]
@@ -827,6 +830,7 @@ pub enum StoreEvent {
     SqliteError,
     LdapError,
     ElasticsearchError,
+    MeilisearchError,
     RedisError,
     S3Error,
     AzureError,
