@@ -445,7 +445,7 @@ impl EventType {
             EventType::Eval(EvalEvent::StoreNotFound) => 140,
             EventType::TaskQueue(TaskQueueEvent::BlobNotFound) => 141,
             EventType::MessageIngest(MessageIngestEvent::FtsIndex) => 142,
-            EventType::Spam(SpamEvent::TrainAccount) => 143,
+            EventType::Spam(SpamEvent::TrainSampleAdded) => 143,
             EventType::TaskQueue(TaskQueueEvent::TaskLocked) => 144,
             EventType::TaskQueue(TaskQueueEvent::MetadataNotFound) => 145,
             EventType::Housekeeper(HousekeeperEvent::Run) => 146,
@@ -668,7 +668,7 @@ impl EventType {
             EventType::Purge(PurgeEvent::InProgress) => 367,
             EventType::Purge(PurgeEvent::Running) => 368,
             EventType::Purge(PurgeEvent::Started) => 369,
-            EventType::Purge(PurgeEvent::TombstoneCleanup) => 370,
+            EventType::Purge(PurgeEvent::BlobCleanup) => 370,
             EventType::PushSubscription(PushSubscriptionEvent::Error) => 371,
             EventType::PushSubscription(PushSubscriptionEvent::NotFound) => 372,
             EventType::PushSubscription(PushSubscriptionEvent::Success) => 373,
@@ -786,13 +786,13 @@ impl EventType {
             EventType::Smtp(SmtpEvent::VrfyDisabled) => 488,
             EventType::Smtp(SmtpEvent::VrfyNotFound) => 489,
             EventType::Spam(SpamEvent::Classify) => 490,
-            EventType::Spam(SpamEvent::ClassifyError) => 491,
+            EventType::Spam(SpamEvent::TrainSampleNotFound) => 491,
             EventType::Store(StoreEvent::HttpStoreFetch) => 492,
             EventType::Store(StoreEvent::HttpStoreError) => 493,
             EventType::Spam(SpamEvent::PyzorError) => 494,
-            EventType::Spam(SpamEvent::Train) => 495,
-            EventType::Spam(SpamEvent::TrainBalance) => 496,
-            EventType::Spam(SpamEvent::TrainError) => 497,
+            EventType::Spam(SpamEvent::TrainCompleted) => 495,
+            EventType::Spam(SpamEvent::ModelNotReady) => 496,
+            EventType::Spam(SpamEvent::ModelNotFound) => 497,
             EventType::Spf(SpfEvent::Fail) => 498,
             EventType::Spf(SpfEvent::Neutral) => 499,
             EventType::Spf(SpfEvent::None) => 500,
@@ -894,6 +894,10 @@ impl EventType {
             EventType::Calendar(CalendarEvent::ItipMessageReceived) => 584,
             EventType::Calendar(CalendarEvent::ItipMessageError) => 585,
             EventType::TaskQueue(TaskQueueEvent::TaskIgnored) => 586,
+            EventType::TaskQueue(TaskQueueEvent::TaskFailed) => 587,
+            EventType::Spam(SpamEvent::TrainStarted) => 588,
+            EventType::Spam(SpamEvent::ModelLoaded) => 589,
+            EventType::Store(StoreEvent::MeilisearchError) => 590,
         }
     }
 
@@ -1037,7 +1041,7 @@ impl EventType {
             140 => Some(EventType::Eval(EvalEvent::StoreNotFound)),
             141 => Some(EventType::TaskQueue(TaskQueueEvent::BlobNotFound)),
             142 => Some(EventType::MessageIngest(MessageIngestEvent::FtsIndex)),
-            143 => Some(EventType::Spam(SpamEvent::TrainAccount)),
+            143 => Some(EventType::Spam(SpamEvent::TrainSampleAdded)),
             144 => Some(EventType::TaskQueue(TaskQueueEvent::TaskLocked)),
             145 => Some(EventType::TaskQueue(TaskQueueEvent::MetadataNotFound)),
             146 => Some(EventType::Housekeeper(HousekeeperEvent::Run)),
@@ -1296,7 +1300,7 @@ impl EventType {
             367 => Some(EventType::Purge(PurgeEvent::InProgress)),
             368 => Some(EventType::Purge(PurgeEvent::Running)),
             369 => Some(EventType::Purge(PurgeEvent::Started)),
-            370 => Some(EventType::Purge(PurgeEvent::TombstoneCleanup)),
+            370 => Some(EventType::Purge(PurgeEvent::BlobCleanup)),
             371 => Some(EventType::PushSubscription(PushSubscriptionEvent::Error)),
             372 => Some(EventType::PushSubscription(PushSubscriptionEvent::NotFound)),
             373 => Some(EventType::PushSubscription(PushSubscriptionEvent::Success)),
@@ -1414,13 +1418,13 @@ impl EventType {
             488 => Some(EventType::Smtp(SmtpEvent::VrfyDisabled)),
             489 => Some(EventType::Smtp(SmtpEvent::VrfyNotFound)),
             490 => Some(EventType::Spam(SpamEvent::Classify)),
-            491 => Some(EventType::Spam(SpamEvent::ClassifyError)),
+            491 => Some(EventType::Spam(SpamEvent::TrainSampleNotFound)),
             492 => Some(EventType::Store(StoreEvent::HttpStoreFetch)),
             493 => Some(EventType::Store(StoreEvent::HttpStoreError)),
             494 => Some(EventType::Spam(SpamEvent::PyzorError)),
-            495 => Some(EventType::Spam(SpamEvent::Train)),
-            496 => Some(EventType::Spam(SpamEvent::TrainBalance)),
-            497 => Some(EventType::Spam(SpamEvent::TrainError)),
+            495 => Some(EventType::Spam(SpamEvent::TrainCompleted)),
+            496 => Some(EventType::Spam(SpamEvent::ModelNotReady)),
+            497 => Some(EventType::Spam(SpamEvent::ModelNotFound)),
             498 => Some(EventType::Spf(SpfEvent::Fail)),
             499 => Some(EventType::Spf(SpfEvent::Neutral)),
             500 => Some(EventType::Spf(SpfEvent::None)),
@@ -1526,6 +1530,10 @@ impl EventType {
             584 => Some(EventType::Calendar(CalendarEvent::ItipMessageReceived)),
             585 => Some(EventType::Calendar(CalendarEvent::ItipMessageError)),
             586 => Some(EventType::TaskQueue(TaskQueueEvent::TaskIgnored)),
+            587 => Some(EventType::TaskQueue(TaskQueueEvent::TaskFailed)),
+            588 => Some(EventType::Spam(SpamEvent::TrainStarted)),
+            589 => Some(EventType::Spam(SpamEvent::ModelLoaded)),
+            590 => Some(EventType::Store(StoreEvent::MeilisearchError)),
             _ => None,
         }
     }
