@@ -7,7 +7,7 @@
 use std::fmt::Debug;
 
 use directory::{
-    QueryBy, ROLE_USER, Type,
+    QueryParams, ROLE_USER, Type,
     backend::{RcptType, internal::manage::ManageDirectory},
 };
 use mail_send::Credentials;
@@ -51,11 +51,11 @@ async fn ldap_directory() {
         assert_eq!(
             handle
                 .query(
-                    QueryBy::Credentials(&Credentials::Plain {
+                    QueryParams::credentials(&Credentials::Plain {
                         username: "john".into(),
                         secret: "12345".into()
-                    }),
-                    true
+                    })
+                    .with_return_member_of(true)
                 )
                 .await
                 .unwrap()
@@ -82,11 +82,11 @@ async fn ldap_directory() {
         assert_eq!(
             handle
                 .query(
-                    QueryBy::Credentials(&Credentials::Plain {
+                    QueryParams::credentials(&Credentials::Plain {
                         username: "bill".into(),
                         secret: "password".into()
-                    }),
-                    true
+                    })
+                    .with_return_member_of(true)
                 )
                 .await
                 .unwrap()
@@ -111,11 +111,11 @@ async fn ldap_directory() {
         assert!(
             handle
                 .query(
-                    QueryBy::Credentials(&Credentials::Plain {
+                    QueryParams::credentials(&Credentials::Plain {
                         username: "bill".into(),
                         secret: "invalid".into()
-                    }),
-                    true
+                    })
+                    .with_return_member_of(true)
                 )
                 .await
                 .unwrap()
@@ -126,7 +126,7 @@ async fn ldap_directory() {
     // Get user by name
     assert_eq!(
         handle
-            .query(QueryBy::Name("jane"), true)
+            .query(QueryParams::name("jane").with_return_member_of(true))
             .await
             .unwrap()
             .unwrap()
@@ -153,7 +153,7 @@ async fn ldap_directory() {
     // Get group by name
     assert_eq!(
         handle
-            .query(QueryBy::Name("sales"), true)
+            .query(QueryParams::name("sales").with_return_member_of(true))
             .await
             .unwrap()
             .unwrap()
