@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2020 Stalwart Labs Ltd <hello@stalw.art>
+ * SPDX-FileCopyrightText: 2020 Stalwart Labs LLC <hello@stalw.art>
  *
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
@@ -474,11 +474,7 @@ async fn eval_dynvalue() {
     ]);
     let core = Server::default();
 
-    for test_name in config
-        .sub_keys("eval", "")
-        .map(|s| s.to_string())
-        .collect::<Vec<_>>()
-    {
+    for test_name in config.sub_keys("eval", "") {
         //println!("============= Testing {:?} ==================", key);
         let if_block = IfBlock::try_parse(
             &mut config,
